==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/WplataSkladnikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class WplataSkladnikKey extends GenericDPSObject {
    /**
     * WPLATA_SKLADNIK.WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wplataId;

    /**
     * WPLATA_SKLADNIK.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzeniePozycjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WPLATA_SKLADNIK.WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWplataId() {
        return wplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * WPLATA_SKLADNIK.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @return WPLATA_SKLADNIK.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * WPLATA_SKLADNIK.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        WplataSkladnikKey other = (WplataSkladnikKey) that;
        return (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", wplataId=").append(wplataId);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/WplataSkladnikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class WplataSkladnikKey extends GenericDPSObject {
    /**
     * WPLATA_SKLADNIK.WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wplataId;

    /**
     * WPLATA_SKLADNIK.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzeniePozycjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WPLATA_SKLADNIK.WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWplataId() {
        return wplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * WPLATA_SKLADNIK.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @return WPLATA_SKLADNIK.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * WPLATA_SKLADNIK.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        WplataSkladnikKey other = (WplataSkladnikKey) that;
        return (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", wplataId=").append(wplataId);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append("]");
        return sb.toString();
    }
}
